<?php
/**
 * EasysmsInterface File Doc Comment
 * PHP Version 7.1
 *
 * @category EasysmsInterface
 * @package  EasySMS
 * @author   Tern <info@tern.gr>
 * @license  https://easysms.gr/license EasySms
 * @link     https://easysms.gr
 */
namespace Tern\Smsplugin\Api\Data;

/**
 * EasysmsInterface interface Doc Comment
 * PHP Version 7.1
 *
 * @category EasysmsInterface
 * @package  EasySMS
 * @author   Tern <info@tern.gr>
 * @license  https://easysms.gr EasySMS
 * @link     https://easysms.gr
 */
interface EasysmsInterface
{
    /**#@+
     * Constants for keys of data array. 
     * Identical to the name of the getter in snake case
     */
    const EASYSMS_ID       = 'easysms_id';
    const SEND_TSTAMP      = 'send_tstamp';
    const SENDER           = 'sender';
    const RECEIVER         = 'receiver';
    const MESSAGE          = 'message';
    const STATUS           = 'status';
    const STATUS_TSTAMP    = 'status_tstamp';
    const GSM_ENCODING     = 'gsm_encoding';
    const ORDER_ID         = 'order_id';
    const API_SMS_ID       = 'api_sms_id';
    /**#@-*/


    /**
     * Get Sent Date/Time
     *
     * @return string|null
     */
    public function getSendTstamp();

    /**
     * Get SMS sender
     *
     * @return string|null
     */
    public function getSender();

    /**
     * Get SMS receiver
     *
     * @return string|null
     */
    public function getReceiver();

    /**
     * Get SMS message
     *
     * @return string|null
     */
    public function getMessage();

    /**
     * Get SMS status
     *
     * @return string|null
     */
    public function getStatus();

    /**
     * Get Date/Time of status update
     *
     * @return string|null
     */
    public function getStatusTstamp();

    /**
     * Get SMS encoding (true if GSM, false if unicode)
     *
     * @return boolean|null
     */
    public function getGsmEncoding();

    /**
     * Get order's id related to this message
     *
     * @return int|null
     */
    public function getOrderId();

    /**
     * Get id of easysms's server related to this message
     *
     * @return int|null
     */
    public function getApiSmsId();

    /**
     * Get ID
     *
     * @return int|null
     */
    public function getId();

    /**
     * Set Sent Date/Time
     *
     * @param @var $creation_time creation time
     *
     * @return $this
     */
    public function setSendTstamp($creation_time);

    /**
     * Set SMS Sender
     *
     * @param @var $sender sender
     *
     * @return $this
     */
    public function setSender($sender);

    /**
     * Set SMS Receiver
     *
     * @param @var $receiver receiver
     *
     * @return $this
     */
    public function setReceiver($receiver);

    /**
     * Set Message
     *
     * @param @var $message message
     *
     * @return $this
     */
    public function setMessage($message);

    /**
     * Set SMS status
     *
     * @param @var $status status
     *
     * @return $this
     */
    public function setStatus($status);

    /**
     * Set Date/Time when status was updated
     *
     * @param @var $updated_time time of update
     *
     * @return $this
     */
    public function setStatusTstamp($updated_time);

    /**
     * Set true if encoding is GSM, false if it is unicode
     *
     * @param @var $isGsm is GSM encoding
     *
     * @return $this
     */
    public function setGsmEncoding($isGsm);

    /**
     * Assign an order id to this SMS
     *
     * @param @var $order_id id of order
     *
     * @return $this
     */
    public function setOrderId($order_id);

    /**
     * Assign the id set on easysms's server to this SMS
     *
     * @param @var $api_sms_id id of sms on easysms's server
     *
     * @return $this
     */
    public function setApiSmsId($api_sms_id);

    /**
     * Set ID
     *
     * @param @var $id id of sms
     *
     * @return $this
     */
    public function setId($id);
}



