<?php
/**
 * List contents of tern_easysms table
 * PHP Version 7.1
 *
 * @category EasysmsList
 * @package  EasySMS
 * @author   Tern <info@tern.gr>
 * @license  https://easysms.gr/license EasySms
 * @link     https://easysms.gr
 */
namespace Tern\Smsplugin\Block;

use Magento\Framework\View\Element\Template;
use Magento\Store\Model\ScopeInterface;
use Magento\Backend\Block\Template\Context;
use Tern\Smsplugin\Model\ResourceModel\Easysms\Collection as EasysmsCollection;
use \Tern\Smsplugin\Model\ResourceModel\Easysms\CollectionFactory;

/**
 * EasysmsList class Doc Comment
 * PHP Version 7.1
 *
 * @category EasysmsList
 * @package  EasySMS
 * @author   Tern <info@tern.gr>
 * @license  https://easysms.gr/license EasySms
 * @link     https://easysms.gr
 */
class EasysmsList extends Template
{
    /**
     * Easysms collection
     *
     * @var EasysmsCollection
     */
    protected $easysmsCollection;

    /**
     * Easysms resource model
     *
     * @var CollectionFactory
     */
    protected $easysmsColFactory;

    /**
     * Constructor
     *
     * @param Context           $context           context
     * @param CollectionFactory $collectionFactory factory
     * @param array             $data              data
     */
    public function __construct(
        Context $context,
        CollectionFactory $collectionFactory,
        array $data = []
    ) {
        $this->_easysmsColFactory = $collectionFactory;
        parent::__construct(
            $context,
            $data
        );
    }

    /**
     * Get Header from configuration value
     *
     * @return string
     */
    public function getHeader()
    {
        return $this->_scopeConfig->getValue(
            'tern_smsplugin/easysms/header', 
            ScopeInterface::SCOPE_STORE
        );
    }

    /**
     * Get Easysms Items Collection
     *
     * @return EasysmsCollection
     */
    public function getEasysmsItems()
    {
        if (null === $this->_easysmsCollection) {
            $this->_easysmsCollection = $this->_easysmsColFactory->create();
        }
        return $this->_easysmsCollection;
    }
} 


