<?php
/**
 * Main File Doc Comment
 * PHP Version 7.1
 *
 * @category Main
 * @package  EasySms
 * @author   Tern <info@tern.gr>
 * @license  https://easysms.gr/license EasySms
 * @link     https://easysms.gr
 */
namespace Tern\Smsplugin\Block;

use Magento\Framework\View\Element\Template\Context as Context;
use Tern\Smsplugin\Model\EasysmsFactory as EasysmsFactory;

/**
 * Main Class Doc Comment
 *
 * @category Main
 * @package  EasySms
 * @author   Tern <info@tern.gr>
 * @license  https://easysms.gr/license EasySms
 * @link     https://easysms.gr
 */
class Main extends \Magento\Framework\View\Element\Template
{
    protected $easysmsFactory;
    protected $status_allowed_values = ["s", "b", "d", "f"];
    const SMS_ID_INDEX_NAME = "msgid";
    const STATUS_INDEX_NAME = "status";

    /**
    * Function __construct
    *
    * Constructor
    *
    * @param Context        $context        context
    * @param EasysmsFactory $easysmsFactory easysmsFactory
    *
    * @return object
    */
    public function __construct(
        Context $context,
        EasysmsFactory $easysmsFactory
    ) {
    
        $this->easysmsFactory = $easysmsFactory;
        parent::__construct($context);
    }

    /**
    * Function getSmsByApiId
    *
    * Retrieves the sms with this id from the db
    *
    * @param @var $sms_id_index index of variable _GET
    *
    * @return EasySms
    */
    function getSmsByApiId($sms_id_index)
    {
        if (array_key_exists($sms_id_index, $_GET) && $_GET[$sms_id_index] > 0) {
            $smsFactory = $this->easysmsFactory->create();
            return $smsFactory->getCollection()
                ->addFieldToFilter('api_sms_id', $_GET[$sms_id_index])
                ->getFirstItem();
        } else {
            return null;
        }
    }

    /**
    * Function isStatusValid
    *
    * Checks if the input status value is valid
    *
    * @param @var $new_status status value
    *
    * @return boolean
    */
    function isStatusValid($new_status)
    {
        return in_array($new_status, $this->status_allowed_values);
    }

    /**
    * Function updateStatus
    *
    * Updates the status of input SMS
    *
    * @param EasySms $sms          sms
    * @param @var    $status_index name of the _GET variable 
    *                              where the new status should be
    *
    * @return void
    */
    function updateStatus($sms,$status_index)
    {
        if (array_key_exists($status_index, $_GET) 
            && $_GET[$status_index] !== null
        ) {
            if ($this->isStatusValid($_GET[$status_index])) {
                $sms->setStatus($_GET[$status_index]);
                $sms->setStatusTstamp(date("Y-m-d H:i:s"));
                $sms->save();
            }
        }
    }

    /**
    * Function _prepareLayout
    *
    * Creates the layout of the frontend output
    *
    * @return void
    */
    function _prepareLayout()
    {
        $smsCalled = $this->getSmsByApiId(self::SMS_ID_INDEX_NAME);

        if ($smsCalled !== null) {
            $this->updateStatus($smsCalled, self::STATUS_INDEX_NAME);
            var_dump($smsCalled->getData());
        }

        var_dump($smsCalled->getData());
        exit;
    }
}



