<?php
/**
 * Send File Doc Comment
 * PHP Version 7.1
 *
 * @category Send
 * @package  EasySms
 * @author   Tern <info@tern.gr>
 * @license  https://easysms.gr/license EasySms
 * @link     https://easysms.gr
 */
namespace Tern\Smsplugin\Controller\Adminhtml\System\Config;

use Magento\Backend\App\Action;
use Magento\Backend\App\Action\Context;
use Magento\Framework\Controller\Result\JsonFactory;
use Magento\Customer\Api\CustomerRepositoryInterface as CustomerInterface;
use Magento\Customer\Api\AddressRepositoryInterface as AddressInterface;
use Tern\Smsplugin\Helper\CustomerData;
use Tern\Smsplugin\Helper\Data;

/**
 * Send Class Doc Comment
 *
 * @category Send
 * @package  EasySms
 * @author   Tern <info@tern.gr>
 * @license  https://easysms.gr/license EasySms
 * @link     https://easysms.gr
 */
class Send extends Action
{

    protected $resultJsonFactory;
    protected $customerInterface;
    protected $addressInterface;
    protected $customer_helper;
    protected $helper;

    /**
     * Constructor
     *
     * @param Context           $context           context
     * @param JsonFactory       $resultJsonFactory resultJsonFactory
     * @param Data              $helper            helper
     * @param CustomerData      $customer_helper   customer_helper
     * @param CustomerInterface $customerInterface customerInterface
     * @param AddressInterface  $addressInterface  addressInterface
     */
    public function __construct(
        Context $context,
        JsonFactory $resultJsonFactory,
        Data $helper,
        CustomerData $customer_helper,
        CustomerInterface $customerInterface,
        AddressInterface $addressInterface
    ) {
    
        parent::__construct($context);
        $this->resultJsonFactory = $resultJsonFactory;
        $this->helper = $helper;
        $this->customer_helper = $customer_helper;
        $this->customerInterface = $customerInterface;
        $this->addressInterface = $addressInterface;
    }

    /**
     * Collect relations data
     *
     * @return \Magento\Framework\Controller\Result\Json
     */
    public function execute()
    {
        $resultJson = $this->resultJsonFactory->create();

        $smsSent = 0;

        $apikey = $this->helper->getEasysmsApiKey();

        $senderId = $this->helper->getEasysmsMassSender();

        $encoding = $this->helper->getEasysmsMassEncoding();

        $message = $this->helper->getEasysmsMassMessage();

        $params = $this->getRequest()->getParams();
        foreach ($params as $x=>$y) {
            if (is_numeric($x)) {
                $receiverId = $this->customer_helper->getPhoneFromAddress($y);
                if (!is_null($receiverId)) {
                    $this->helper
                        ->sendSms(
                            $apikey, $senderId, 
                            $receiverId, $encoding, $message
                        );
                    $smsSent++;
                }
            }
        }

        return $resultJson->setData(['success' => true, 'time' => $smsSent]);
    }
}




