<?php
/**
 * Data File Doc Comment
 * PHP Version 7.1
 *
 * @category Data
 * @package  EasySMS
 * @author   Tern <info@tern.gr>
 * @license  https://easysms.gr/license EasySms
 * @link     https://easysms.gr
 */
namespace Tern\Smsplugin\Helper;

use Magento\Store\Model\ScopeInterface;
use Magento\Framework\App\Helper\AbstractHelper;
use Magento\Framework\App\Helper\Context;
use Tern\Smsplugin\Model\Easysms;

/**
 * Data class Doc Comment
 * PHP Version 7.1
 *
 * @category Data
 * @package  EasySMS
 * @author   Tern <info@tern.gr>
 * @license  https://easysms.gr/license EasySms
 * @link     https://easysms.gr
 */
class Data extends AbstractHelper
{
    protected $easysms;
    protected $easysms_apibasepath = 'https://www.easysms.gr/api/';
    protected $easysms_api_sendsms = 'sms/send';
    protected $easysms_api_callback 
        = 'http://163.172.111.60/magento/magento2/tern_smsplugin';

    const ORDERSPATH = 'tern_smsplugin_orders';
    const ACTIONSPATH = 'tern_smsplugin_actions';
    const MASSPATH = 'tern_smsplugin_masssms';
    const APIKEY = self::ACTIONSPATH.'/basic_actions/smsplugin_apikey';
    const NEWORDER_ENABLED = self::ORDERSPATH.'/new_order/smsplugin_new_order_enabled';
    const NEWORDER_SENDERID
        = self::ORDERSPATH.'/new_order/smsplugin_new_order_sender_id';
    const ADMIN_NEWORDER_SENDERID
        = self::ORDERSPATH.'/admin_actions/smsplugin_admin_oncustomercheckout_sender_id';
    const NEWORDER_ENCODING = self::ORDERSPATH.'/new_order/smsplugin_new_order_encoding';
    const ADMIN_NEWORDER_ENCODING = self::ORDERSPATH
        .'/admin_actions/smsplugin_admin_oncustomercheckout_encoding';
    const NEWORDER_MESSAGE = self::ORDERSPATH.'/new_order/smsplugin_new_order_message';
    const ADMIN_NEWORDER_MESSAGE = self::ORDERSPATH
        .'/admin_actions/smsplugin_admin_oncustomercheckout_message';
    const STATUS_ENABLED 
        = self::ORDERSPATH.'/order_status_change/smsplugin_order_status_change_enabled';
    const STATUS_SENDERID 
        = self::ORDERSPATH
        .'/order_status_change/smsplugin_order_status_change_sender_id';
    const ADMIN_STATUS_SENDERID = self::ORDERSPATH
        .'/admin_actions/smsplugin_admin_onorderstatuschange_sender_id';
    const ADMIN_STATUS_ENCODING = self::ORDERSPATH
        .'/admin_actions/smsplugin_admin_onorderstatuschange_encoding';
    const ADMIN_STATUS_MESSAGE = self::ORDERSPATH
        .'/admin_actions/smsplugin_admin_onorderstatuschange_message';
    const STATUS_ENCODING 
        = self::ORDERSPATH.'/order_status_change/smsplugin_order_status_change_encoding';
    const STATUS_MESSAGE 
        = self::ORDERSPATH.'/order_status_change/smsplugin_order_status_change_message';
    const ADMIN_ENABLED = self::ORDERSPATH.'/admin_actions/smsplugin_admin_enabled';
    const ADMIN_MOBILE = self::ORDERSPATH.'/admin_actions/smsplugin_admin_mobile';
    const ADMIN_ONNEWORDER 
        = self::ORDERSPATH.'/admin_actions/smsplugin_admin_oncustomercheckout';
    const ADMIN_ONSTATUS 
        = self::ORDERSPATH.'/admin_actions/smsplugin_admin_onorderstatuschange';
    const ADMIN_ONNEWACCOUNT
        = self::ORDERSPATH.'/admin_actions/smsplugin_admin_onnewaccount';
    const ADMIN_NEWACCOUNT_SENDERID 
        = self::ORDERSPATH.'/admin_actions/smsplugin_admin_onnewaccount_sender_id';
    const ADMIN_NEWACCOUNT_ENCODING 
        = self::ORDERSPATH.'/admin_actions/smsplugin_admin_onnewaccount_encoding';
    const ADMIN_NEWACCOUNT_MESSAGE 
        = self::ORDERSPATH.'/admin_actions/smsplugin_admin_onnewaccount_message';
    const MASS_SENDER = self::MASSPATH.'/masssms/smsplugin_masssms_sender_id';
    const MASS_ENCODING = self::MASSPATH.'/masssms/smsplugin_masssms_encoding';
    const MASS_MESSAGE = self::MASSPATH.'/masssms/smsplugin_masssms_message';
    const MASS_RECEIVERS = self::MASSPATH.'/masssms/smsplugin_send';

    /**
     * Constructor
     *
     * @param Context $context context
     * @param Easysms $easysms easysms
     */
    public function __construct(
        Context $context,
        Easysms $easysms
    ) {
        $this->easysms = $easysms;
        parent::__construct($context);
    }

    /**
     * Getting API Key
     *
     * @return string
     */
    public function getEasysmsApiKey()
    {
        return $this->_getConfig(self::APIKEY);
    }


    /**
     * Checking Admin SMS is enabled or not, on new order
     *
     * @return string
     */
    public function isEasysmsNewOrderNotificationsEnabled()
    {
        return $this->_getConfig(self::NEWORDER_ENABLED);
    }

    /**
     * Getting sender number on new order
     *
     * @return string
     */
    public function getEasysmsNewOrderSenderId()
    {
        return $this->_getConfig(self::NEWORDER_SENDERID);
    }

    /**
     * Getting sender number on new order (admin notification)
     *
     * @return string
     */
    public function getAdminNeworderSender()
    {
        return $this->_getConfig(self::ADMIN_NEWORDER_SENDERID);
    }

    /**
     * Getting message for new order
     *
     * @return string
     */
    public function getEasysmsNewOrderMessage()
    {
        return $this->_getConfig(self::NEWORDER_MESSAGE);
    }

    /**
     * Getting message for new order (admin notification)
     *
     * @return string
     */
    public function getAdminNeworderMessage()
    {
        return $this->_getConfig(self::ADMIN_NEWORDER_MESSAGE);
    }

    /**
     * Getting encoding for new order
     *
     * @return string
     */
    public function getEasysmsNewOrderEncoding()
    {
        return $this->_getConfig(self::NEWORDER_ENCODING);
    }

    /**
     * Getting encoding for new order (admin notification)
     *
     * @return string
     */
    public function getAdminNeworderEncoding()
    {
        return $this->_getConfig(self::ADMIN_NEWORDER_ENCODING);
    }

    /**
     * Checking Admin SMS is enabled or not on order status change
     *
     * @return string
     */
    public function isEasysmsOrderStatusChangedNotificationsEnabled()
    {
        return $this->_getConfig(self::STATUS_ENABLED);
    }

    /**
     * Getting sender number on order status change
     *
     * @return string
     */
    public function getEasysmsStatusChangedSenderId()
    {
        return $this->_getConfig(self::STATUS_SENDERID);
    }

    /**
     * Getting sender number on order status change (admin notification)
     *
     * @return string
     */
    public function getAdminStatusSender()
    {
        return $this->_getConfig(self::ADMIN_STATUS_SENDERID);
    }

    /**
     * Getting encoding for order status change
     *
     * @return string
     */
    public function getEasysmsStatusChangedEncoding()
    {
        return $this->_getConfig(self::STATUS_ENCODING);
    }

    /**
     * Getting encoding for order status change (admin notification)
     *
     * @return string
     */
    public function getAdminStatusEncoding()
    {
        return $this->_getConfig(self::ADMIN_STATUS_ENCODING);
    }

    /**
     * Getting message for order status change
     *
     * @return string
     */
    public function getEasysmsStatusChangedMessage()
    {
        return $this->_getConfig(self::STATUS_MESSAGE);
    }

    /**
     * Getting message for order status change (admin notification)
     *
     * @return string
     */
    public function getAdminStatusMessage()
    {
        return $this->_getConfig(self::ADMIN_STATUS_MESSAGE);
    }

    /**
     * Getting sender of the mass SMS
     *
     * @return string
     */
    public function getEasysmsMassSender()
    {
        return $this->_getConfig(self::MASS_SENDER);
    }

    /**
     * Getting encoding of the mass SMS
     *
     * @return string
     */
    public function getEasysmsMassEncoding()
    {
        return $this->_getConfig(self::MASS_ENCODING);
    }

    /**
     * Getting message of the mass SMS
     *
     * @return string
     */
    public function getEasysmsMassMessage()
    {
        return $this->_getConfig(self::MASS_MESSAGE);
    }

    /**
     * Getting receivers' list of Mass message
     *
     * @return string
     */
    public function getEasysmsMassReceivers()
    {
        return $this->_getConfig(self::MASS_RECEIVERS);
    }


    /**
     * Getting sender number on account registration
     *
     * @return string
     */
    public function getEasysmsNewAccountSenderId()
    {
        return $this->_getConfig(self::ADMIN_NEWACCOUNT_SENDERID);
    }

    /**
     * Getting message for account registration
     *
     * @return string
     */
    public function getEasysmsNewAccountMessage()
    {
        return $this->_getConfig(self::ADMIN_NEWACCOUNT_MESSAGE);
    }

    /**
     * Getting encoding for account registration
     *
     * @return string
     */
    public function getEasysmsNewAccountEncoding()
    {
        return $this->_getConfig(self::ADMIN_NEWACCOUNT_ENCODING);
    }

    /**
     * Checking if Admin SMS notification is enabled or not
     *
     * @return string
     */
    public function isEasysmsAdminNotificationsEnabled()
    {
        return $this->_getConfig(self::ADMIN_ENABLED);
    }

    /**
     * Getting Admin Mobile Number
     *
     * @return string
     */
    public function getEasysmsAdminMobile()
    {
        return $this->_getConfig(self::ADMIN_MOBILE);
    }

    /**
     * Checking if Admin SMS notification is enabled or not for new order
     *
     * @return string
     */
    public function isEasysmsAdminNotifiedOnNewOrder()
    {
        if ($this->isEasysmsAdminNotificationsEnabled()) {
            return $this->_getConfig(self::ADMIN_ONNEWORDER);
        } else {
            return 0;
        }
    }

    /**
     * Checking if Admin SMS notification is enabled or not on order status change
     *
     * @return string
     */
    public function isEasysmsAdminNotifiedOnStatusChanged()
    {
        if ($this->isEasysmsAdminNotificationsEnabled()) {
            return $this->_getConfig(self::ADMIN_ONSTATUS);
        } else {
            return 0;
        }
    }

    /**
     * Checking if Admin SMS notification is enabled or not 
     * on new account registration
     *
     * @return string
     */
    public function isEasysmsAdminNotifiedOnNewAccount()
    {
        if ($this->isEasysmsAdminNotificationsEnabled()) {
            return $this->_getConfig(self::ADMIN_ONNEWACCOUNT);
        } else {
            return 0;
        }
    }

    /**
     * Sends the SMS
     *
     * @param @var $apikey     the API key
     * @param @var $senderId   number or name of the sender
     * @param @var $receiverId number or name of the receiver
     * @param @var $encoding   text encoding
     * @param @var $message    message
     *
     * @return void
     */
    public function sendSms($apikey, $senderId, $receiverId, $encoding, $message)
    {
        $is_ucs = $this->_isUcsEncoding($encoding);
        $apipath = $this->easysms_apibasepath
                    . $this->easysms_api_sendsms;
        $apidata = '?key='.urlencode($apikey)
                    . '&to='.urlencode($receiverId)
                    . '&from='.urlencode($senderId)
                    . '&text='.urlencode($message)
                    . '&ucs='.urlencode($is_ucs)
                    . '&callback='.urlencode($this->easysms_api_callback)
                    . '&type=json';
        $apiurl = $apipath.$apidata;
        $curl_output = json_decode($this->cURL($apiurl));
        if ($curl_output->{'error'} === "0") {
            $this->storeSms(
                $curl_output->{'id'}, $senderId, $receiverId, 
                $is_ucs, $message, $curl_output
                    ->{'status'}
            );
        }

    }

    /**
     * Stores the SMS into the database
     *
     * @param @var $msgId       message id
     * @param @var $senderId    number or name of the sender
     * @param @var $destination number or name of the receiver
     * @param @var $is_ucs      true if encoding is unicode
     * @param @var $message     message
     * @param @var $status      sms status
     *
     * @return void
     */
    public function storeSms($msgId, $senderId, $destination, 
        $is_ucs, $message, $status
    ) {
    
        $this->easysms->setApiSmsId($msgId);
        $this->easysms->setSender($senderId);
        $this->easysms->setReceiver($destination);
        $this->easysms->setGsmEncoding($is_ucs);
        $this->easysms->setMessage($message);
        $this->easysms->setStatus($status);
        $this->easysms->save();
    }

    /**
     * Send Actions path to this function and get the module admin Config data
     *
     * @param @var $configPath configuration path
     *
     * @return string
     */
    private function _getConfig($configPath)
    {
        return $this->scopeConfig->getValue(
            $configPath,
            ScopeInterface::SCOPE_STORE
        );
    }

    /**
     * Curl Function to get the result from SmspluginSMS API
     *
     * @param @var $url url to send to the API
     *
     * @return string
     */
    public function cURL($url)
    {
        return file_get_contents($url);
        /*$ch = curl_init();
        curl_setopt($ch, CURLOPT_HEADER, 0);
        curl_setopt($ch, CURLOPT_RETURNTRANSFER, 1);
        curl_setopt($ch, CURLOPT_URL, $url);
        $data = curl_exec($ch);
        curl_close($ch);
        return $data;*/
    }

    /**
     * Replies true if the encoding is Unicode or not, false otherwise
     *
     * @param @var $encoding encoding
     *
     * @return boolean
     */
    private function _isUcsEncoding($encoding)
    {
        if ($encoding === "Unicode") {
            return true;
        } else {
            return false;
        }
    }

}



