<?php
/**
 * Tern Mass Send SMS to Customers
 * PHP Version 7.1
 *
 * @category CustomerOptions
 * @package  Tern_Smsplugin
 * @author   Tern <info@tern.gr>
 * @license  https://easysms.gr/license EasySms
 * @link     https://easysms.gr
 */
namespace Tern\Smsplugin\Model\Config\Source;

use Magento\Framework\Option\ArrayInterface;
use Magento\Customer\Api\CustomerRepositoryInterface as CustomerRepository;
use Magento\Framework\Api\SearchCriteriaBuilder;

/**
 * CustomerOptions class Doc Comment
 * PHP Version 7.1
 *
 * @category CustomerOptions
 * @package  EasySMS
 * @author   Tern <info@tern.gr>
 * @license  https://easysms.gr/license EasySms
 * @link     https://easysms.gr
 */
class CustomerOptions implements ArrayInterface
{

    protected $customerRepository;
    protected $searchCriteriaBuilder;

    /**
     * Constructor
     *
     * @param CustomerRepository    $customerRepository    customerRepository
     * @param SearchCriteriaBuilder $searchCriteriaBuilder searchCriteriaBuilder
     * */
    public function __construct(
        CustomerRepository $customerRepository,
        SearchCriteriaBuilder $searchCriteriaBuilder
    ) {
    
        $this->customerRepository    = $customerRepository;
        $this->searchCriteriaBuilder = $searchCriteriaBuilder;
    }

    /**
     * Option getter
     *
     * @return array
     */
    public function toOptionArray()
    {
        $arr = $this->toArray();
        $ret = [];

        foreach ($arr as $key => $value) {
            $ret[] = [
                'value' => $key,
                'label' => $value
            ];
        }

        return $ret;
    }

    /**
     * Get options in "key-value" format
     *
     * @return array
     */
    public function toArray()
    {
        $searchCriteria = $this->searchCriteriaBuilder->create();
        $customers      = $this->customerRepository
            ->getList($searchCriteria)->getItems();

        $customersList = array();
        foreach ($customers as $customer) {
            $customersList[$customer->getId()] 
                = __($customer->getFirstname() . ' ' . $customer->getLastname());
        }

        return $customersList;
    }


}


