<?php
/**
 * Easysms File Doc Comment
 * PHP Version 7.1
 *
 * @category Easysms
 * @package  EasySMS
 * @author   Tern <info@tern.gr>
 * @license  https://easysms.gr/license EasySms
 * @link     https://easysms.gr
 */
namespace Tern\Smsplugin\Model;

use Magento\Framework\Model\AbstractModel;
use Magento\Framework\DataObject\IdentityInterface;
use Tern\Smsplugin\Api\Data\EasysmsInterface;

/**
 * Easysms Class Doc Comment
 * PHP Version 7.1
 *
 * @category                                       Easysms
 * @package                                        Tern\Smsplugin\Model
 * @author                                         Tern <info@tern.gr>
 * @license                                        https://easysms.gr/license EasySms
 * @link                                           https://easysms.gr
 * @SuppressWarnings(PHPMD.CouplingBetweenObjects)
 */
class Easysms extends AbstractModel implements EasysmsInterface, IdentityInterface
{
    /**
     * Cache tag
     */
    const CACHE_TAG = 'tern_smsplugin_easysms';

    /**
     * Easysms Initialization
     *
     * @return void
     */
    protected function _construct()
    {
        $this->_init('Tern\Smsplugin\Model\ResourceModel\Easysms');
    }


    /**
     * Get Sent Date/Time
     *
     * @return string|null
     */
    public function getSendTstamp()
    {
        return $this->getData(self::SEND_TSTAMP);
    }

    /**
     * Get SMS sender
     *
     * @return string|null
     */
    public function getSender()
    {
        return $this->getData(self::SENDER);
    }

    /**
     * Get SMS receiver
     *
     * @return string|null
     */
    public function getReceiver()
    {
        return $this->getData(self::RECEIVER);
    }

    /**
     * Get SMS message
     *
     * @return string|null
     */
    public function getMessage()
    {
        return $this->getData(self::MESSAGE);
    }

    /**
     * Get SMS status
     *
     * @return string|null
     */
    public function getStatus()
    {
        return $this->getData(self::STATUS);
    }

    /**
     * Get Date/Time of status update
     *
     * @return string|null
     */
    public function getStatusTstamp()
    {
        return $this->getData(self::STATUS_TSTAMP);
    }

    /**
     * Get SMS encoding (true if GSM, false if unicode)
     *
     * @return boolean|null
     */
    public function getGsmEncoding()
    {
        return $this->getData(self::GSM_ENCODING);
    }

    /**
     * Get order's id related to this message
     *
     * @return int|null
     */
    public function getOrderId()
    {
        return $this->getData(self::ORDER_ID);
    }

    /**
     * Get easysms's server id related to this message
     *
     * @return int|null
     */
    public function getApiSmsId()
    {
        return $this->getData(self::API_SMS_ID);
    }

    /**
     * Get ID
     *
     * @return int|null
     */
    public function getId()
    {
        return $this->getData(self::EASYSMS_ID);
    }

    /**
     * Return identities
     *
     * @return string[]
     */
    public function getIdentities()
    {
        return [self::CACHE_TAG . '_' . $this->getId()];
    }

    /**
     * Set Sent Date/Time
     * TODO Remove input argument and set current time
     *
     * @param string $creation_time time of creation
     *
     * @return $this
     */
    public function setSendTstamp($creation_time)
    {
        return $this->setData(self::SEND_TSTAMP, $creation_time);
    }

    /**
     * Set SMS Sender
     *
     * @param string $sender sender
     *
     * @return $this
     */
    public function setSender($sender)
    {
        return $this->setData(self::SENDER, $sender);
    }

    /**
     * Set SMS Receiver
     *
     * @param string $receiver receiver
     *
     * @return $this
     */
    public function setReceiver($receiver)
    {
        return $this->setData(self::RECEIVER, $receiver);
    }

    /**
     * Set Message
     *
     * @param string $message message
     *
     * @return $this
     */
    public function setMessage($message)
    {
        return $this->setData(self::MESSAGE, $message);
    }

    /**
     * Set SMS status
     * TODO enlist all possible values. Check for errors before setting
     *
     * @param string $status status
     *
     * @return $this
     */
    public function setStatus($status)
    {
        return $this->setData(self::STATUS, $status);
    }

    /**
     * Set Date/Time when status was updated
     * TODO Remove input argument and set current time
     *
     * @param string $updated_time time of status update
     *
     * @return $this
     */
    public function setStatusTstamp($updated_time)
    {
        return $this->setData(self::STATUS_TSTAMP, $updated_time);
    }

    /**
     * Set true if encoding is GSM, false if it is unicode
     *
     * @param boolean $isGsm encoding is GSM
     *
     * @return $this
     */
    public function setGsmEncoding($isGsm)
    {
        return $this->setData(self::GSM_ENCODING, $isGsm);
    }

    /**
     * Assign an order id to this SMS
     *
     * @param int $order_id id of an order associated with this SMS
     *
     * @return $this
     */
    public function setOrderId($order_id)
    {
        return $this->setData(self::ORDER_ID, $order_id);
    }

    /**
     * Assign the easysms's server id to this SMS
     *
     * @param int $api_sms_id easysms's server id
     *
     * @return $this
     */
    public function setApiSmsId($api_sms_id)
    {
        return $this->setData(self::API_SMS_ID, $api_sms_id);
    }

    /**
     * Set ID
     *
     * @param int $id id
     *
     * @return $this
     */
    public function setId($id)
    {
        return $this->setData(self::EASYSMS_ID, $id);
    }
}



