<?php
/**
 * Easysms MySQL Resource
 * PHP Version 7.1
 *
 * @category Easysms
 * @package  EasySms
 * @author   Tern <info@tern.gr>
 * @license  https://easysms.gr/license EasySms
 * @link     https://easysms.gr
 */
namespace Tern\Smsplugin\Model\ResourceModel;

use Magento\Framework\Model\ResourceModel\Db\AbstractDb;

/**
 * Easysms Class Doc Comment
 *
 * @category Easysms
 * @package  EasySms
 * @author   Tern <info@tern.gr>
 * @license  https://easysms.gr/license EasySms
 * @link     https://easysms.gr
 */
class Easysms extends AbstractDb
{

    /**
     * Date
     *
     * @var DateTime
     */
    protected $_date;

    /**
     * Construct
     *
     * @param Context  $context        context
     * @param DateTime $date           date
     * @param string   $connectionName connectionName
     */
    public function __construct(
        \Magento\Framework\Model\ResourceModel\Db\Context $context,
        \Magento\Framework\Stdlib\DateTime\DateTime $date,
        $connectionName = null
    ) {
        parent::__construct($context, $connectionName);
        $this->_date = $date;
    }

    /**
     * Initialize resource model
     *
     * @return void
     */
    protected function _construct()
    {
        $this->_init('tern_easysms', 'easysms_id');
    }


    /**
     * Process page data before saving
     *
     * @param \Magento\Framework\Model\AbstractModel $object object
     *
     * @return $this
     * @throws \Magento\Framework\Exception\LocalizedException
     */
    protected function _beforeSave(\Magento\Framework\Model\AbstractModel $object)
    {

        if ($object->isObjectNew() && !$object->hasCreationTime()) {
            $object->setCreationTime($this->_date->gmtDate());
        }

        $object->setUpdateTime($this->_date->gmtDate());

        return parent::_beforeSave($object);
    }

} 


