<?php
/**
 * Actions performed on a new order event
 * PHP Version 7.1
 *
 * @category NewOrder
 * @package  EasySms
 * @author   Tern <info@tern.gr>
 * @license  https://easysms.gr/license EasySms
 * @link     https://easysms.gr
 */
namespace Tern\Smsplugin\Observer;

use Magento\Framework\Event\Observer       as Observer;
use Magento\Framework\Event\ObserverInterface;
use Magento\Framework\View\Element\Context as Context;
use Tern\Smsplugin\Helper\Data                 as Helper;
use Tern\Smsplugin\Helper\CustomerData                 as CustomerHelper;
use Tern\Smsplugin\Model\Easysms               as Easysms;
use Tern\Smsplugin\Model\EasysmsFactory        as EasysmsFactory;

/**
 * New Order Observer
 *
 * @category NewOrder
 * @package  EasySms
 * @author   Tern <info@tern.gr>
 * @license  https://easysms.gr/license EasySms
 * @link     https://easysms.gr
 */
class NewOrder implements ObserverInterface
{
    const AJAX_PARAM_NAME = 'infscroll';
    const AJAX_HANDLE_NAME = 'infscroll_ajax_request';

    /**
     * Helper for SmspluginSMS Module
     *
     * @var \Tern\Smsplugin\Helper\Data
     */
    protected $helper;
    protected $customer_helper;

    /**
     * Sender ID
     *
     * @var $senderId
     */
    protected $senderId;

    /**
     * Destination
     *
     * @var $destination
     */
    protected $destination;

    /**
     * Message
     *
     * @var $message
     */
    protected $message;

    /**
     * Whether Enabled or not
     *
     * @var $enabled
     */
    protected $enabled;

    /**
     * Constructor
     *
     * @param Context        $context         context
     * @param Helper         $helper          helper
     * @param CustomerHelper $customer_helper customer_helper
     */
    public function __construct(
        Context $context,
        Helper $helper,
        CustomerHelper $customer_helper
    ) {
        $this->helper  = $helper;
        $this->customer_helper  = $customer_helper;
    }

    /**
     * The execute class
     *
     * @param Observer $observer observer
     *
     * @return void
     */
    public function execute(Observer $observer)
    {
        if ($this->customer_helper->isNewOrder($_SERVER['REQUEST_URI'])) {

            $this->apikey   = $this->helper->getEasysmsApiKey();

            $this->senderId = $this->helper->getEasysmsNewOrderSenderId();

            $this->message  = $this->helper->getEasysmsNewOrderMessage();

            $this->encoding  = $this->helper->getEasysmsNewOrderEncoding();

            $this->enabled  = $this->helper->isEasysmsNewOrderNotificationsEnabled();

            if ($this->enabled == 1) {

                $order             = $this->customer_helper->getOrder($observer);

                $orderData         = $this->customer_helper->getOrderData($order);

                $this->destination = $this->customer_helper
                    ->getCustomerPhone($observer);

                if ($this->destination !== null) {

                    $this->message     = $this->customer_helper
                        ->replaceKeywords($this->message, $orderData);

                    $this->helper->sendSms(
                        $this->apikey,
                        $this->senderId,
                        $this->destination,
                        $this->encoding,
                        $this->message
                    );

                    if ($this->helper->isEasysmsAdminNotifiedOnNewOrder()==1) {

                        $this->senderId = $this->helper->getAdminNeworderSender();

                        $this->destination  = $this->helper->getEasysmsAdminMobile();

                        $this->encoding  = $this->helper->getAdminNeworderEncoding();

                        $this->message  = $this->helper->getAdminNeworderMessage();

                        $this->message     = $this->customer_helper
                            ->replaceKeywords($this->message, $orderData);

                        $this->helper->sendSms(
                            $this->apikey,
                            $this->senderId,
                            $this->destination,
                            $this->encoding,
                            $this->message
                        );
                    }
                }
            }
        }
    }
}




