<?php
/**
 * Actions performed on a new customer registration
 * PHP Version 7.1
 *
 * @category Registration
 * @package  EasySms
 * @author   Tern <info@tern.gr>
 * @license  https://easysms.gr/license EasySms
 * @link     https://easysms.gr
 */
namespace Tern\Smsplugin\Observer;

use Magento\Framework\Event\Observer       as Observer;
use Magento\Framework\Event\ObserverInterface;
use Magento\Framework\View\Element\Context as Context;
use Tern\Smsplugin\Helper\Data                 as Helper;
use Tern\Smsplugin\Helper\CustomerData                 as CustomerHelper;
use Tern\Smsplugin\Model\Easysms               as Easysms;
use Tern\Smsplugin\Model\EasysmsFactory        as EasysmsFactory;

/**
 * Customer registration observer
 *
 * @category Registration
 * @package  EasySms
 * @author   Tern <info@tern.gr>
 * @license  https://easysms.gr/license EasySms
 * @link     https://easysms.gr
 */
class Registration implements ObserverInterface
{
    const AJAX_PARAM_NAME = 'infscroll';
    const AJAX_HANDLE_NAME = 'infscroll_ajax_request';

    /**
     * Helper for SmspluginSMS Module
     *
     * @var \Tern\Smsplugin\Helper\Data
     */
    protected $helper;
    protected $customer_helper;

    /**
     * Sender ID
     *
     * @var $senderId
     */
    protected $senderId;

    /**
     * Destination
     *
     * @var $destination
     */
    protected $destination;

    /**
     * Message
     *
     * @var $message
     */
    protected $message;

    /**
     * Whether Enabled or not
     *
     * @var $enabled
     */
    protected $enabled;

    /**
     * Constructor
     *
     * @param Context        $context         context
     * @param Helper         $helper          helper
     * @param CustomerHelper $customer_helper customer helper
     */
    public function __construct(
        Context $context,
        Helper $helper,
        CustomerHelper $customer_helper
    ) {
        $this->helper  = $helper;
        $this->customer_helper  = $customer_helper;
    }

    /**
     * The execute class
     *
     * @param Observer $observer observer
     *
     * @return void
     */
    public function execute(Observer $observer)
    {
        $this->apikey   = $this->helper->getEasysmsApiKey();

        $this->senderId = $this->helper->getEasysmsNewAccountSenderId();

        $this->message  = $this->helper->getEasysmsNewAccountMessage();

        $this->encoding  = $this->helper->getEasysmsNewAccountEncoding();

        $this->enabled  = $this->helper->isEasysmsAdminNotificationsEnabled();

        if ($this->enabled == 1) {

            if ($this->helper->isEasysmsAdminNotifiedOnNewAccount()==1) {

                $customerData = $this->customer_helper->getCustomerData($observer);

                $this->destination = $this->helper->getEasysmsAdminMobile();

                $this->message     = $this->customer_helper
                    ->replaceKeywords($this->message, $customerData);

                $this->helper->sendSms(
                    $this->apikey,
                    $this->senderId,
                    $this->destination,
                    $this->encoding,
                    $this->message
                );

            }
        }
    }
}



