<?php
/**
 * InstallSchema File Doc Comment
 * PHP Version 7.1
 *
 * @category InstallSchema
 * @package  EasySMS
 * @author   Tern <info@tern.gr>
 * @license  https://easysms.gr/license EasySms
 * @link     https://easysms.gr
 */
namespace Tern\Smsplugin\Setup;

use Magento\Framework\Setup\InstallSchemaInterface;
use Magento\Framework\Setup\ModuleContextInterface;
use Magento\Framework\Setup\SchemaSetupInterface;
use Magento\Framework\DB\Ddl\Table;

/**
 * MyClass Class Doc Comment
 * PHP Version 7.1
 *
 * @category InstallSchema
 * @package  EasySMS
 * @author   Tern <info@tern.gr>
 * @license  https://easysms.gr/license EasySms
 * @link     https://easysms.gr
 */
class InstallSchema implements InstallSchemaInterface
{
    /**
     * Install tables
     *
     * @param SchemaSetupInterface   $setup   the installer
     * @param ModuleContextInterface $context the context
     * 
     * @return                                        void
     * @SuppressWarnings(PHPMD.ExcessiveMethodLength)
     */
    public function install(SchemaSetupInterface $setup, 
        ModuleContextInterface $context
    ) {
        $setup->startSetup();

        $table = $setup->getConnection()->newTable(
            $setup->getTable('tern_easysms')
        )->addColumn(
            'easysms_id',
            Table::TYPE_SMALLINT,
            null,
            ['identity' => true, 'nullable' => false, 'primary' => true],
            'Easysms ID'
        )->addColumn(
            'api_sms_id',
            Table::TYPE_INTEGER,
            null,
            ['nullable' => true, 'default' => null, 'unsigned' => true],
            'Id of SMS saved on easysms\'s side'
        )->addColumn(
            'send_tstamp',
            Table::TYPE_TIMESTAMP,
            null,
            ['nullable' => false, 'default' => Table::TIMESTAMP_INIT],
            'date/time when the SMS was sent'
        )->addColumn(
            'sender',
            Table::TYPE_TEXT,
            16,
            ['nullable' => false],
            'Name of SMS Sender'
        )->addColumn(
            'receiver',
            Table::TYPE_TEXT,
            16,
            ['nullable' => false],
            'Number of SMS Receiver'
        )->addColumn(
            'message',
            Table::TYPE_TEXT,
            null,
            ['nullable' => false],
            'SMS message'
        )->addColumn(
            'status',
            Table::TYPE_TEXT,
            null,
            ['nullable' => false],
            'SMS status: s, b, d or f'
        )->addColumn(
            'status_tstamp',
            Table::TYPE_TIMESTAMP,
            null,
            ['nullable' => false, 'default' => Table::TIMESTAMP_INIT],
            'date/time when the SMS status was updated'
        )->addColumn(
            'gsm_encoding',
            Table::TYPE_BOOLEAN,
            null,
            ['nullable' => false, 'default' => true],
            'encoding, false is unicode'
        )->addColumn(
            'order_id',
            Table::TYPE_INTEGER,
            null,
            ['nullable' => true, 'default' => null, 'unsigned' => true],
            'Id of order related to this sms'
        )->setComment('SMSplugin - SMS');

        $setup->getConnection()->createTable($table);

        $setup->endSetup();
    }
}
