<?php
/**
 * Update database table(s)
 * PHP Version 7.1
 *
 * @category UpgradeSchema
 * @package  EasySms
 * @author   Tern <info@tern.gr>
 * @license  https://easysms.gr/license EasySms
 * @link     https://easysms.gr
 */
namespace Tern\Smsplugin\Setup;

use Magento\Framework\DB\Ddl\Table;
use Magento\Framework\Setup\UpgradeSchemaInterface;
use Magento\Framework\Setup\ModuleContextInterface;
use Magento\Framework\Setup\SchemaSetupInterface;

/**
 * UpgradeSchema Class Comment
 *
 * @category UpgradeSchema
 * @package  EasySms
 * @author   Tern <info@tern.gr>
 * @license  https://easysms.gr/license EasySms
 * @link     https://easysms.gr
 */
class UpgradeSchema implements UpgradeSchemaInterface
{
    /**
     * Install tables
     *
     * @param SchemaSetupInterface   $setup   setup
     * @param ModuleContextInterface $context context
     *
     * @return void
     */
    public function upgrade(SchemaSetupInterface $setup, 
        ModuleContextInterface $context
    ) {
          $writer = new \Zend\Log\Writer\Stream(BP . '/var/log/1test.log');
        $logger = new \Zend\Log\Logger();
        $logger->addWriter($writer);
        $logger->info('1');
 
        $setup->startSetup();

        if (version_compare($context->getVersion(), '1.0.2') < 0) {
            $tableName = $setup->getTable('tern_easysms');

            if ($setup->getConnection()->isTableExists($tableName) != true) {
                $table = $setup->getConnection()
                    ->newTable($tableName)
                    ->addColumn(
                        'easysms_id',
                        \Magento\Framework\DB\Ddl\Table::TYPE_SMALLINT,
                        null,
                        ['identity' => true, 'nullable' => false, 'primary' => true],
                        'Easysms ID'
                    )
                    ->addColumn(
                        'api_sms_id',
                        \Magento\Framework\DB\Ddl\Table::TYPE_INTEGER,
                        null,
                        ['nullable' => true, 'default' => null, 'unsigned' => true],
                        'Id of SMS saved on easysms\'s side'
                    )
                    ->addColumn(
                        'send_tstamp',
                        \Magento\Framework\DB\Ddl\Table::TYPE_TIMESTAMP,
                        null,
                        ['nullable' => false, 'default' => Table::TIMESTAMP_INIT],
                        'date/time when the SMS was sent'
                    )
                    ->addColumn(
                        'sender',
                        \Magento\Framework\DB\Ddl\Table::TYPE_TEXT,
                        16,
                        ['nullable' => false],
                        'Name of SMS Sender'
                    )
                    ->addColumn(
                        'receiver',
                        \Magento\Framework\DB\Ddl\Table::TYPE_TEXT,
                        16,
                        ['nullable' => false],
                        'Number of SMS Receiver'
                    )
                    ->addColumn(
                        'message',
                        \Magento\Framework\DB\Ddl\Table::TYPE_TEXT,
                        null,
                        ['nullable' => false],
                        'SMS message'
                    )
                    ->addColumn(
                        'status',
                        \Magento\Framework\DB\Ddl\Table::TYPE_TEXT,
                        null,
                        ['nullable' => false],
                        'SMS status: s, b, d or f'
                    )
                    ->addColumn(
                        'status_tstamp',
                        \Magento\Framework\DB\Ddl\Table::TYPE_TIMESTAMP,
                        null,
                        ['nullable' => false, 'default' => Table::TIMESTAMP_INIT],
                        'date/time when the SMS status was updated'
                    )
                    ->addColumn(
                        'gsm_encoding',
                        \Magento\Framework\DB\Ddl\Table::TYPE_BOOLEAN,
                        null,
                        ['nullable' => false, 'default' => true],
                        'encoding, false is unicode'
                    )
                    ->addColumn(
                        'order_id',
                        \Magento\Framework\DB\Ddl\Table::TYPE_INTEGER,
                        null,
                        ['nullable' => true, 'default' => null, 'unsigned' => true],
                        'Id of order related to this sms'
                    )
                    ->setComment('SMSplugin - SMS');
                   $setup->getConnection()->createTable($table);
            }
        }

        $setup->endSetup();
    }
}

